QuadMesh signature
~~~~~~~~~~~~~~~~~~
The ``QuadMesh`` signature ::

    def __init__(meshWidth, meshHeight, coordinates,
                 antialiased=True, shading='flat', **kwargs)

is deprecated and replaced by the new signature ::

    def __init__(coordinates, *, antialiased=True, shading='flat', **kwargs)

In particular:

- *coordinates* must now be a (M, N, 2) array-like. Previously, the grid
  shape was separately specified as (*meshHeight* + 1, *meshWidth* + 1) and
  *coordinates* could be an array-like of any shape with M * N * 2 elements.
- all parameters except *coordinates* are keyword-only now.
